@@ -18,7 +18,7 @@ pub fn encrypt<T: Serialize>(
     // `unwrap` here is fine because `IV` is set here and the only error returned is: `InvalidKeyIvLength`
     // and this must never happen
     let cipher: Aes256 =
-        Aes256::new_var(token_encryption_key_str.as_bytes(), IV.as_bytes()).unwrap();
+        Aes256::new_from_slices(token_encryption_key_str.as_bytes(), IV.as_bytes()).unwrap();
     Ok(cipher.encrypt_vec(json.as_bytes()))
 }
 
@@ -29,7 +29,7 @@ pub fn decrypt<T: DeserializeOwned>(
     // `unwrap` here is fine because `IV` is set here and the only error returned is: `InvalidKeyIvLength`
     // and this must never happen
     let cipher: Aes256 =
-        Aes256::new_var(token_encryption_key_str.as_bytes(), IV.as_bytes()).unwrap();
+        Aes256::new_from_slices(token_encryption_key_str.as_bytes(), IV.as_bytes()).unwrap();
     let decrypted: Vec<u8> = cipher.decrypt_vec(encrypted)?;
     Ok(serde_json::from_slice(decrypted.as_slice())?)
 }
